// $Id: CaptureTool.java,v 1.6 2001/05/26 22:51:12 pcharles Exp $

/***************************************************************************
 * Copyright (C) 2001, Patrick Charles and Jonas Lehmann                   *
 * Distributed under the Mozilla Public License                            *
 *   http://www.mozilla.org/NPL/MPL-1.1.txt                                *
 ***************************************************************************/
package net.sourceforge.jpcap.client;

import com.fooware.util.CommandLine;
import net.ultrametrics.console.TestConsole;
import net.sourceforge.jpcap.net.RawPacket;
import net.sourceforge.jpcap.net.Packet;
import net.sourceforge.jpcap.capture.RawPacketListener;
import net.sourceforge.jpcap.capture.PacketListener;
import net.sourceforge.jpcap.capture.PacketCapture;
import net.sourceforge.jpcap.capture.CaptureDeviceNotFoundException;


/**
 * Tool with text console for controlling packet capture.
 *
 * @author Patrick Charles and Jonas Lehmann
 * @version $Revision: 1.6 $
 * @lastModifiedBy $Author: pcharles $
 * @lastModifiedAt $Date: 2001/05/26 22:51:12 $
 */
public class CaptureTool implements RawPacketListener, PacketListener
{
  /**
   * Create a new capture tool.
   */
  public CaptureTool() {
    initializeSystem();
    initializeConsole();

    // activate the ui by default
    if(Settings.ENABLE_UI_DEFAULT)
      activateUi();
  }


  // implementation of RawPacketListener interface

  public void rawPacketArrived(RawPacket rawPacket) {
    if(mode.equals(MODE_RAW) || mode.equals(MODE_VERBOSE)) 
      System.err.println(rawPacket + " captured");
  }


  // implementation of PacketListener interface

  public void packetArrived(Packet packet) {
    if(mode.equals(MODE_OBJECT) || mode.equals(MODE_VERBOSE))
      System.err.println(packet);

    if(mode.equals(MODE_TERSE)) 
      System.err.print(".");

    history.add(packet);

    if(uiVisible)
      viewFrame.update(packet);
  }


  // implementation of tool logic

  /**
   * Initialize the packet capture system.
   */
  protected void initializeSystem() {
    packetCapture = new PacketCapture();
    packetCapture.addRawPacketListener(this);
    packetCapture.addPacketListener(this);

    try {
      System.err.println("attempting to find network device.. ");
      device = packetCapture.findDevice();
      System.err.println("using device '" + device + "'.");
    }
    catch(CaptureDeviceNotFoundException e) {
      System.err.println("No suitable capture device could be found!");
      System.err.println("You can't run this tool without a network device.");
      System.err.println("If one exists but wasn't detected, " + 
                         "specify it using 'device'.");

      // System.err.println(e);
    }
  }

  /**
   * Initialize the tool's console.
   */
  protected void initializeConsole() {
    console = new CaptureConsole(this, packetCapture);
    // create the console's command-line processor
    CommandLine cl = new CommandLine(console); 
    cl.setPromptString("CaptureTool> ");
    cl.start();
  }

  /**
   * Clear the capture history.
   */
  public void clearHistory() {
    history.clear();
  }

  /**
   * Dump the capture history buffer contents.
   */
  public int dumpHistory() {
    return history.dump();
  }

  /**
   * Active the graphical packet view.
   */
  public boolean activateUi() {
    uiVisible = !uiVisible;
    viewFrame.setVisible(uiVisible);

    if(uiVisible)
      viewFrame.refresh(history);

    return uiVisible;
  }

  /**
   * Set the capture device name.
   */
  public void setDevice(String device) {
    this.device = device;
  }

  /**
   * Fetch the capture device name.
   */
  public String getDevice() {
    return device;
  }

  /**
   * Set the capture mode.
   */
  public void setMode(String mode) {
    this.mode = mode;
  }

  /**
   * Check if a proposed mode is valid.
   */
  public static boolean isModeValid(String pmode) {
    return 
      pmode.equals(MODE_RAW) || pmode.equals(MODE_OBJECT) ||
      pmode.equals(MODE_TERSE) || pmode.equals(MODE_VERBOSE);
  }

  /**
   * Fetch the capture mode.
   */
  public String getMode() {
    return mode;
  }

  /**
   * Packet capture.
   */
  public static void main(String [] args) {
    CaptureTool captureTool = new CaptureTool();
  }


  /**
   * The console handling commands for this capture tool.
   */
  CaptureConsole console;

  /**
   * Packet capture system.
   */
  PacketCapture packetCapture;

  /**
   * Packet capture device name.
   */
  private String device = null;

  /**
   * Captured packet history.
   */
  CaptureHistory history = new CaptureHistory();

  /**
   * Graphical view of captured packets.
   */
  CaptureViewFrame viewFrame = new CaptureViewFrame();

  /**
   * Whether or not the ui is visible.
   */
  boolean uiVisible = false;


  // capture modes..
  protected static String MODE_RAW = "raw";
  protected static String MODE_OBJECT = "object";
  protected static String MODE_VERBOSE = "verbose";
  protected static String MODE_TERSE = "terse";

  /**
   * Capture mode.
   */
  private String mode = MODE_OBJECT;


  private String _rcsid = 
    "$Id: CaptureTool.java,v 1.6 2001/05/26 22:51:12 pcharles Exp $";
}
