// $Id: IPProtocols.java,v 1.2 2001/05/23 02:46:52 pcharles Exp $

/***************************************************************************
 * Copyright (C) 2001, Patrick Charles and Jonas Lehmann                   *
 * Distributed under the Mozilla Public License                            *
 *   http://www.mozilla.org/NPL/MPL-1.1.txt                                *
 ***************************************************************************/
package net.sourceforge.jpcap.net;


/**
 * Code constants for well-defined IP protocols.
 * <p>
 * Taken from netinet/in.h
 *
 * @author Patrick Charles and Jonas Lehmann
 * @version $Revision: 1.2 $
 * @lastModifiedBy $Author: pcharles $
 * @lastModifiedAt $Date: 2001/05/23 02:46:52 $
 */
public interface IPProtocols
{
  /**
   * Dummy protocol for TCP. 
   */
  int IPPROTO_IP = 0;

  /**
   * IPv6 Hop-by-Hop options. 
   */
  int IPPROTO_HOPOPTS = 0;

  /**
   * Internet Control Message Protocol. 
   */
  int IPPROTO_ICMP = 1;

  /**
   * Internet Group Management Protocol.
   */
  int IPPROTO_IGMP = 2;

  /**
   * IPIP tunnels (older KA9Q tunnels use 94). 
   */
  int IPPROTO_IPIP = 4;

  /**
   * Transmission Control Protocol. 
   */
  int IPPROTO_TCP = 6;

  /**
   * Exterior Gateway Protocol. 
   */
  int IPPROTO_EGP = 8;

  /**
   * PUP protocol. 
   */
  int IPPROTO_PUP = 12;

  /**
   * User Datagram Protocol. 
   */
  int IPPROTO_UDP = 17;

  /**
   * XNS IDP protocol. 
   */
  int IPPROTO_IDP = 22;

  /**
   * SO Transport Protocol Class 4. 
   */
  int IPPROTO_TP = 29;

  /**
   * IPv6 header. 
   */
  int IPPROTO_IPV6 = 41;

  /**
   * IPv6 routing header. 
   */
  int IPPROTO_ROUTING = 43;

  /**
   * IPv6 fragmentation header. 
   */
  int IPPROTO_FRAGMENT = 44;

  /**
   * Reservation Protocol. 
   */
  int IPPROTO_RSVP = 46;

  /**
   * General Routing Encapsulation. 
   */
  int IPPROTO_GRE = 47;

  /**
   * encapsulating security payload. 
   */
  int IPPROTO_ESP = 50;

  /**
   * authentication header. 
   */
  int IPPROTO_AH = 51;

  /**
   * ICMPv6. 
   */
  int IPPROTO_ICMPV6 = 58;

  /**
   * IPv6 no next header. 
   */
  int IPPROTO_NONE = 59;

  /**
   * IPv6 destination options. 
   */
  int IPPROTO_DSTOPTS = 60;

  /**
   * Multicast Transport Protocol. 
   */
  int IPPROTO_MTP = 92;

  /**
   * Encapsulation Header. 
   */
  int IPPROTO_ENCAP = 98;

  /**
   * Protocol Independent Multicast. 
   */
  int IPPROTO_PIM = 103;

  /**
   * Compression Header Protocol. 
   */
  int IPPROTO_COMP = 108;

  /**
   * Raw IP packets. 
   */
  int IPPROTO_RAW = 255;


  /**
   * Unrecognized IP protocol.
   * WARNING: this only works because the int storage for the protocol
   * code has more bits than the field in the IP header where it is stored.
   */
  int IPPROTO_INVALID = -1;
}
