// $Id: LinkLayers.java,v 1.1 2001/05/24 03:18:50 pcharles Exp $

/***************************************************************************
 * Copyright (C) 2001, Patrick Charles and Jonas Lehmann                   *
 * Distributed under the Mozilla Public License                            *
 *   http://www.mozilla.org/NPL/MPL-1.1.txt                                *
 ***************************************************************************/
package net.sourceforge.jpcap.net;


/**
 * Link-layer type codes.
 * <p>
 * Taken from libpcap/bpf/net/bpf.h
 * <p>
 * The link-layer type is used to determine what data-structure the 
 * IP protocol bits will be encapsulated inside of.
 * <p>
 * On a 10/100mbps network, packets are encapsulated inside of ethernet
 * 14-byte ethernet headers which contain MAC addresses and an ethernet type 
 * field.
 * <p>
 * On ethernet over ppp network, the link-layer type is raw, and packets 
 * are not encapsulated in any ethernet header. 
 * NOTE: why isn't it type PPP instead?
 * <p>
 *
 * @author Patrick Charles and Jonas Lehmann
 * @version $Revision: 1.1 $
 * @lastModifiedBy $Author: pcharles $
 * @lastModifiedAt $Date: 2001/05/24 03:18:50 $
 */
public interface LinkLayers
{
  /**
   * no link-layer encapsulation 
   */
  int DLT_NULL = 0;

  /**
   * Ethernet (10Mb) 
   */
  int DLT_EN10MB = 1;

  /**
   * Experimental Ethernet (3Mb) 
   */
  int DLT_EN3MB = 2;

  /**
   * Amateur Radio AX.25 
   */
  int DLT_AX25 = 3;

  /**
   * Proteon ProNET Token Ring 
   */
  int DLT_PRONET = 4;

  /**
   * Chaos 
   */
  int DLT_CHAOS = 5;

  /**
   * IEEE 802 Networks 
   */
  int DLT_IEEE802 = 6;

  /**
   * ARCNET 
   */
  int DLT_ARCNET = 7;

  /**
   * Serial Line IP 
   */
  int DLT_SLIP = 8;

  /**
   * Point-to-point Protocol 
   */
  int DLT_PPP = 9;

  /**
   * FDDI 
   */
  int DLT_FDDI = 10;

  /**
   * LLC/SNAP encapsulated atm 
   */
  int DLT_ATM_RFC1483 = 11;

  /**
   * raw IP 
   */
  int DLT_RAW = 12;
}
